**Example 1: 删除运行时反弹shell事件**



Input: 

```
tccli tcss DeleteReverseShellEvents --cli-unfold-argument  \
    --EventIdSet xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

